@@ -11,7 +11,7 @@ import importlib
 
 class Index(Command):
     def find_model_classes(self):
-        classes = []
+        classes = set()
         model_dir = os.path.join(self.app.app_dir, "models")
         for filename in os.listdir(model_dir):
             if filename.endswith(".py"):
@@ -28,7 +28,7 @@ class Index(Command):
                             StorableModel,
                             ShardedModel,
                         ]:
-                            classes.append(obj)
+                            classes.add(obj)
         return classes
 
     def run(self):
